%Konstantinos Vilaetis 2012
%Demand calculation function
%
%Inputs are: Average temperature, Minimum daily average temperature,
%Minimum daily low temperature, and then building square feet:
%sfEdu Education square feet, sfFsls Food sales square feet, sfFsvc Food service square feet, sfHS Healthcare square feet, sfLgn Lodging square feet, sfRet Retail square feet, sfOff Office square feet, sfPas Public Assembly square feet, sfPOS Public order and safety (police & prisons) square feet, sfRel Religious Worship square feet, sfSvc Service (?) square feet, sfRes Residential square feet
%
%Outputs an array where the first element is yearly demand, the second the
%maximum demand the third the load factor, and the fourth the simulated
%demand of the system
%
%Units are:
%1. Temperature in C
%2. Scaling Factors 1000btu/sqft
%3. Area in sq. ft.
%4. Demand outputs in 1000btu/yr


function [yrdmnd maxdmnd load dmnd PeakUnitDmnd]=DemandFcn(Tave, TminJan, Tabsmin, sfEdu, sfFsvc, sfHS, sfLgn, sfRet, sfOff, sfPas, sfSvc, sfRes, SqFtUnit, TmeanJan)

% TminJan = Tave - (Tave-TminJan)*1.25;
% TmeanJan = Tave - (Tave-TmeanJan)*1.25;
% Tabsmin = Tave - (Tave-Tabsmin)*1.25;

%Scalingfactors SH
scCornell=94.6;     %Cornell average [1000 BTU/yr/sqft]
scUS=34;            %US average
scMA=47;            %Middle Atlantic average

scEdu=39.4;
scFsls=28.9;
scFsvc=43.1;
scHS=70.4;
scLgn=22.2;
scRet=24.8;
scOff=32.8;
scPas=49.7;
scPOS=49.9;
scRel=26.2;
scSvc=35.9;
scRes=25.7; %2001RECS space heating

%WH per sqft:
scWCornell=10.5; %for reference
scWEdu=5.8;
scWFsls=2.9;
scWFsvc=40.4;
scWHS=30.2;
scWLgn=31.4;
scWRet=1.1;
scWOff=2.0;
scWPas=1.0;
scWPOS=14.0;
scWRel=0.8;
scWSvc=1.0;
scWRes=8.0; %2001 RECS

%Temperature Estimation
temp=zeros(365,1);

dmndSH=temp;
dmnd=temp; % initialize the array
totalsqft=sfEdu+sfFsvc+sfHS+sfLgn+sfRet+sfOff+sfPas+sfSvc+sfRes;

i=1:365;

temp=Tave+(Tave-TmeanJan)*sin(2*pi()*(i-112)./365);

%Assume a 5-day cold spell Jan 18-22 based on average January mimumums
temp(18:22) = TminJan;

%temp=temp+3;

%ScalingFactors
% 1. SH
sclSH=(sfEdu*scEdu+sfFsvc*scFsvc+sfHS*scHS+sfLgn*scLgn+sfRet*scRet+sfOff*scOff+sfPas*scPas+sfSvc*scSvc+sfRes*scRes)*(scMA/scUS)/(scCornell*(totalsqft));

% 1. WH (constant through the year)
sclWH=(sfEdu*scWEdu+sfFsvc*scWFsvc+sfHS*scWHS+sfLgn*scWLgn+sfRet*scWRet+sfOff*scWOff+sfPas*scWPas+sfSvc*scWSvc+sfRes*scWRes)/((totalsqft));


%Demand Estimation (SH) still per sqft
dmndSH = (-7.73*temp+162.4)*sclSH;  %1000 BTU/sqft/year (calculated for each day)
dmndSH(dmndSH<0)=0;


%Estimate SH+WH
dmnd=(dmndSH+sclWH).*totalsqft/365; %total demand in 1000btu/day
%Outputs
%1. Load Factor
load=mean(dmnd)/max(dmnd);

%2. Max instant dmnd:
maxdmnd=((-7.73*Tabsmin+162.4)*(sclSH) + sclWH)*totalsqft/365; %1000BTU/day

%4. Average yearly demand:
yrdmnd=sum(dmnd);

%5. Average max demand per housing unit (BTU/hr)
PeakUnitDmnd = ((-7.73*Tabsmin+162.4)*(scRes*((scMA/scUS)/scCornell)) + sclWH)*(SqFtUnit/8765)*1000;

end








