%Lizeta Gkogka 2012
%LCOH and Investment cost for distribution system.  T=90C-140C

%Based on email conversation with Lizeta Gkogk (May, 2016), lower
%temperatures than 90C are okay whereas temperatures above 140C mean a
%change in the piping material.

%Input 1: lentgh. pipe length (m) of network. This is the distance that our 
%pipes are required to travel, in order to cover heat demand in a specific
%city/university

%Input 2. Qmax. Set the demand Qmax you are covering (MW). This is the peak load
%at your design temperature.

%Input 3. Tnetwork. Set the temperature of the network. You can choose between 90C and
%140C, basically choose between 90,95,100,...,140C. (keep step=5)

%input 4: elprice. set the price of electricity (for pumping needs), $/kWh

%input 5: maintenance.  set the maintenance cost. $/Mwh delivered

%input 6: discount, payback. set discount rate and payback time for LCOH calculations (this is
%just for future reference)

%input 7:If you want, set yearly load (MWh). The simplest thing you can do is just let it scale
%it according to Cornell.


function [minIC...
            ,minopannualmillions...
            ,doptimum...
            ,numberoptimum...
            ,Cdist...
            ,PumpIC...
            ,BldgCost...
            ,SystemSetup...
            ,ShaftP...
            ,Energy...
            ,pumpingcost...
            ,PC...
            ,LCOheat...
            ,LCOheatnominator...
            ,LCOheatdenominator...
            ,PeakFuelCost...
            ,PeakBoilerCost...
            ,TotBldgCost1...
            ,TotBldgCost2...
            ,BldgCost1...
            ,BldgCost2]= distcostFcn(Proportion1plant...
                                       ,length_road...
                                       ,MQgeo...
                                       ,Qmax...
                                       ,mf...
                                       ,Tps0...
                                       ,elprice...
                                       ,discount...
                                       ,payback...
                                       ,MassFlowRate...
                                       ,BranchDistance...
                                       ,res_bldgs...
                                       ,res_units...
                                       ,com_bldgs...
                                       ,com_units...
                                       ,detached...
                                       ,attached...
                                       ,bldg2_4...
                                       ,bldg5_19...
                                       ,bldg20_49...
                                       ,bldg50_plus...
                                       ,SqFtUnit...
                                       ,PeakUnitDmnd...
                                       ,RoadCoverage...% Proportion of roads in town with main distribution piping
                                       ,Tsr0...
                                       ,Tss0...
                                       ,HXAreaCentral...
                                       ,U0...
                                       ,Tpr0...
                                       ,networkservice...
                                       ,GasPrice...
                                       ,PeakMW)

%Retrofit options:  %Option 1: assume indirect system - i.e. no central plant, ind'l bldg. HX, etc...
                    %Option 2: assume centralized system - i.e. centralized heat exchange plant, dist. water straight to bldg. radiators...
                    %Else assume no cost for heat exchangers, controls, pumps, branch lines, etc.
                   
% length of the piping system
% length of roads*portion of roads that need pipes
length = length_road*RoadCoverage;              

% density of ?? (kg/m^3)
density=943;

%4-16in diameter (2-8in radius) of pipes. Basically this allows selection
%relatively to mass flow.
r=linspace(2,8,13);


%thresshold for pipe diameter calculation

%find the minimum radius, when installing one pipe. From excel: diameter(maximum) =
%1.5197*massflow^0.427. When radius reaches 6in (diameter=12in),
%extrapolate linearly to find the according diameter.

% gravity constant
g=9.81;

% specific weight (N/m^3)
spweight=density*g;

%assume 60% efficiency for pump;
efficiency=0.6;

%Re>10^6 ..turbulent flow
fmoody=0.027; % friction factor for moody diagram
velocity=zeros(365,13);
hf=zeros(365,13);
DP=zeros(365,13);
PP=zeros(365,13);
ShaftP=zeros(365,13); % shaft power
Energy=zeros(13,1);
rinminimum=zeros(20,1);

%This model allows installation up to 10 pipes. We can add more-if
%reasonable.


%first find the maximum flow
mfmax=0;
for i=1:365
    if mfmax<mf(i)
        mfmax=mf(i);
    end
end

mfmax0 = mfmax;
	
%If total system flow exceeds cap (ten 16" pipes) then build multiple separate networks rather than one giant network
if 	mfmax > 1670;
    mfmax = 1670;
    %mass flow will be divided amongst networks
    mf = mf*(1670/mfmax0);
else 
    mfmax = mfmax0;
end

for i=1:10
    if mfmax>(106.4647*i)
        rinminimum(i)=0.5*(5.5726+0.062183*((1/i)*mfmax));
    else 
        rinminimum(i)=0.5*(1.5197*((1/i)*mfmax)^0.427);
    end
end
    

pipenumber=zeros(13,1);
for k=1:13
    for i=1:365
        for h=1:10
            %find the number of pipes you should install
            %if the selected radius is above the limiting factor, then put
            %h number of pipes. 
              
            if r(k)>rinminimum(h)
                %install h pipes
                velocity(i,k)=mf(i)/(h*density*pi()*((r(k)*0.0254)^2));
                hf(i,k)=fmoody*(length/((r(k)*0.0254)*2))*(velocity(i,k)^2)/(2*g);
                DP(i,k)=spweight*hf(i,k);
                PP(i,k)=DP(i,k)*mf(i)/density;
                %Now find the total loss (all pipes)
                ShaftP(i,k)=h*PP(i,k)/efficiency;
                %we have daily data so the output ShaftP(W) must be multiplied by 24 to
                %derive the daily consumption (Wh)
                Energy(k)=Energy(k)+24*ShaftP(i,k);
                %keep the number of pipes you have selected to install
                pipenumber(k)=h;
  
                %now stop the for-loop since you don't want to install more than needed
                break
            end
            
            %ok, now for very small pipe diameter, when you have very high mass
            %flow, you should take into account that you can't install for example 2in
            %radius..
            if r(k)<rinminimum(10)
                %    %report as infinite power needed
                Energy(k)=10^16;
                ShaftP(i,k)=10^16;
            end
        end % end for loop over h
    end % end for loop overi
end % end for loop over k


MWH=Energy/1000000;
%total pumping cost
pumpingcost=MWH*elprice*1000;

PC=zeros(1,13);

for j=1:13
    PC(j)=pumpingcost(j)/MQgeo;
end


%pumping investment cost
%assume that cost varies proportionally to power output (kW)
%for 800kW purchased cost 30,000$==>with f=3.5: 120000$. No further data for 
%pumping cost function with capacity in Perry's, so assume linear scaling up/down

%find maximum power needed by the pump. 
Shaftmax=zeros(13,1);
Shaftmax=max(ShaftP(:,1:13));

Pneeded=Shaftmax;
%calculate investment cost of pump according to its capacity. scale up/down.
PumpIC=(Pneeded/800000)*120000;


%distribution cost variations according to pipe diameter (corrected)
%y=92.435x + 284.77
%Based on email with Lizeta Gkogka (May, 2016) the use of the new
%development values for retrofitting is okay because paving costs are
%accounted for elsewhere or would be over accounted for now
Cdist=zeros(13,1);
for i=1:13
    if pipenumber(i)==1
      %install one pipe
      %Cdist(i)=length*(79.72*(r(i)*2) + 191.65);  %Assume supply and return line same trench
      %Cdist(i)=length*(55.72*(r(i)*2) + 171.9);  %Assume single loop (no return pipe)
      Cdist(i)=length*(75.82*(r(i)*2) + 83.06);  %Assume new development (no road cutting, repaving, etc.)
      %Cdist(i)=length*(51.81*(r(i)*2) + 63.31);  %Assume BEST CASE development (single pipe, no road cutting, no repaving, etc.)
    elseif pipenumber(i)<6
      %that's just a simplification. We are not really sure how many times we are going to account for paving costs    
      %Cdist(i)=(1+(pipenumber(i)-1)*(1-0.2876))*length*(79.72*(r(i)*2) + 191.65);    %Supply and return pipe
      %Cdist(i)=(1+(pipenumber(i)-1)*(1-0.2876))*length*(55.72*(r(i)*2) + 171.9);    %Assume single loop (no return pipe)
      Cdist(i)=(1+(pipenumber(i)-1)*(1-0.2876))*length*(75.82*(r(i)*2) + 83.06);    %Assume new development (no road cutting, repaving, etc.)
      %Cdist(i)=(1+(pipenumber(i)-1)*(1-0.2876))*length*(51.81*(r(i)*2) + 63.31);    %Assume BEST CASE development (single pipe, no road cutting, no repaving, etc.)
    else
      %Cdist(i)=(2+(pipenumber(i)-2)*(1-0.2876))*length*(79.72*(r(i)*2) + 191.65);    %Supply and return pipe
      %Cdist(i)=(2+(pipenumber(i)-2)*(1-0.2876))*length*(55.72*(r(i)*2) + 171.9);    %Assume single loop (no return pipe)
      Cdist(i)=(2+(pipenumber(i)-2)*(1-0.2876))*length*(75.82*(r(i)*2) + 83.06);    %Assume new development (no road cutting, repaving, etc.)
      %Cdist(i)=(2+(pipenumber(i)-2)*(1-0.2876))*length*(51.81*(r(i)*2) + 63.31);    %Assume BEST CASE development (single pipe, no road cutting, no repaving, etc.)
    end
end

%Now find costs of service lines, heat exchangers, interior equipment, etc.

BldgCost1 = zeros(13,1);
BldgCost2 = zeros(13,1);

Loopin = Tsr0;          %Return temperature of heating loop (secondary fluid from radiators)
Loopout = Tss0;          %Supply temperature of heating loop (secondary fluid to radiators)

%Figure cost of service lines to buildings

BldgCount = [detached; attached; bldg2_4; bldg5_19; bldg20_49; bldg50_plus; com_bldgs];     %Number of buildings of each size category
UnitsPerBldg = [1 2 3 13 35 65 com_units/com_bldgs];                                            %Assumed number units per bldg category (detached, attached, 2-4, 5-19, 20-49, 50+)
PeakLoads = (PeakUnitDmnd*1055/3600)*UnitsPerBldg;                          %Estimated peak load per building [Watts thermal]
ReqKgs = (PeakLoads/(4.2*(Loopout-Loopin)))/1000;                                 %Estimated peak massflow per building [kgs]
ReqSrvcDiam = 1.5197*(ReqKgs.^0.427);                                       %Calculated diameter of req'd service pipes [inches] (from piping spreadsheet)
CostSrvcPerMeter = 130.89*ReqSrvcDiam + 52.348;                             %Estimated cost of service lines for each building type [$/m]
TotSrvcLineCost = CostSrvcPerMeter*BranchDistance*BldgCount;                %Estimated total cost of service lines for community [$]

%Figure cost of building heat exchangers (for retrofit option 1)

GFin = Tps0;                    %Design supply temperature of network (geofluid from well)
GFout = Tpr0;        %Design return temperature of network (geofluid to well)                 

DelT10 = GFin - Loopout;
DelT20 = GFout - Loopin;
LMTD0 = (DelT10 - DelT20)/log(DelT10/DelT20);        %Log mean temperature difference for HX
HXAream = PeakLoads/(U0*LMTD0);                  %Req'd area of HX for buildings [m2]
HXArea = HXAream*10.764;                        %Req'd HX area [ft2]
CostPerFt = 222.36*HXArea.^-0.379;              %Cost of HX [$/ft2]
HXCost = HXArea.*CostPerFt;                             %Cost of HX's for each building category [$]
OtherCost = [2000 2000 3000 5000 5000 8000 2000*com_units/com_bldgs];            %Estimated cost of add'l building components (hot water retrofit, booster pump, etc. - Rafferty 2001) 
NetBldgCost = HXCost + OtherCost;
TotBldgCost1 = NetBldgCost*BldgCount;                        %Total cost of building equipment for retrofit option 1 (heat HX's, pumps, hot water retrofit, booster pump (large bldg only))
TotBldgCost2 = OtherCost*BldgCount;                      %Estiamted cost of building equipment for retrofit option 2 (booster pumps (large bldg only), hot water retrofit)

%Figure cost of interior equipment (per unit)
UnitCost = 3000;                        %Estimated cost of interior heating coil, controls, piping, etc. (Rafferty 2001)

%Peaking equipment calculations
PeakMBTUperHr = PeakMW*3412141/1000;                                   %Excess peak MBTU/hr req'd
PeakBoilerCost0 = max(0,((PeakMBTUperHr)*50)^0.95);                     %Cost of peak boilers (Estimated from CEE 2001) 
PeakBoilerCost(1:13,1) = PeakBoilerCost0;

PeakFuelCost = max(0,(((PeakMBTUperHr*30)/0.8)/1020)*GasPrice);        %Annual cost of peaking fuel in 2011 dollars

%Figure cost if central plant is used (retrofit option 2)
HXAreaCentralft = Proportion1plant*HXAreaCentral*10.764;             %Size of central plant HX

%CentralPlantCost = 49117*log(Qmax)+83651;               %Assumed cost of central heat exchange facility (Rafferty 1996) [$/MWth] (for retrofit option 2)
CentralPlantCost = 34290*log(Qmax)+74987+(222.36*HXAreaCentralft^-0.379)*HXAreaCentralft;     %Assumed cost of central HX facility with new HX sizes... 

BldgCost1(1:13,1) = TotSrvcLineCost*Proportion1plant + (res_units+com_units)*UnitCost*Proportion1plant + TotBldgCost1*Proportion1plant;
BldgCost2(1:13,1) = TotSrvcLineCost*Proportion1plant + (res_units+com_units)*UnitCost*Proportion1plant + TotBldgCost2*Proportion1plant + CentralPlantCost;

BldgCost = zeros(13,1);    
    
if DelT10<=0
  SystemSetup = {'IMPOSSIBLE'};
elseif DelT20<=0
    SystemSetup = {'IMPOSSIBLE'};
elseif BldgCost1(1,1) > BldgCost2(1,1);
    BldgCost = BldgCost2;
    SystemSetup = {'Indirect'};
elseif BldgCost1(1,1) < BldgCost2(1,1);
    BldgCost = BldgCost1;
    SystemSetup = {'Centralized'};
else BldgCost = BldgCost1;
    SystemSetup = {'Either'};
end
 

%now find the total investment cost, consisting of pumps and piping costs.
totalcost=zeros(13,1);

totalcost(:,1)=Cdist(:,1)+PumpIC(:,1)+BldgCost(:,1)+PeakBoilerCost(:,1);

% totalcost = totalcost*1.25;

LCOheat=zeros(13,1);
LCOheatnominator=zeros(13,payback);
LCOheatdenominator=zeros(13,payback);
dolperkwhheat=zeros(13,1);
centsperkwhheat=zeros(13,1);

for t=1:payback
    LCOheatnominator(:,t) = (totalcost + pumpingcost + networkservice*length + PeakFuelCost)/((1+discount)^t);
    LCOheatdenominator(:,t) = MQgeo/((1+discount)^t);
end

for i=1:13
    LCOheat(i) = sum(LCOheatnominator(i,:))/sum(LCOheatdenominator(i,:));
    dolperkwth = LCOheat./1000;
    
    % for j=1:13
    %  
    % LCOheat(j)=0;
    % 
    % LCOheatnominator(j)=(totalcost(j)+(maintenance+PC(j))*MQgeo)/(1+discount);
    % LCOheatdenominator(j)=(MQgeo/((1+discount)));
    % 
    %     for i=2:payback
    %         LCOheatnominator(j)=LCOheatnominator(j)+((maintenance+PC(j)*MQgeo/(1+discount)^i));
    %         LCOheatdenominator(j)=LCOheatdenominator(j)+(MQgeo/((1+discount)^i));
    %     end
    %     
    % LCOheat(j)=LCOheatnominator(j)/LCOheatdenominator(j);
    % dolperkwhheat(j)=LCOheat(j)/1000;
    % centsperkwhheat(j)=dolperkwhheat(j)*100;
    % 
    % 
    % end
   
    %Optimization loop optimized for minimum LCOH
    minLCOH = 10000;
    for j=1:13;
        if dolperkwth(j)<minLCOH;
            minLCOH=dolperkwth(j);
            minIC=totalcost(j);
            minoperating=(networkservice*length+pumpingcost(j))+PeakFuelCost;
            doptimum=2*r(j);
            numberoptimum=pipenumber(j);
        end
    end  

    %minIC = minIC*0.75;
    
    %optimization loop. set an arbitrary value for minimum investment cost.
    %At! optimization only according to Investment cost
    % minIC=10000000000000;
    %     for i=1:13
    %         if minIC>totalcost(i)
    %         minIC=totalcost(i);
    %         minoperating=(maintenance+PC(i));
    %         doptimum=2*r(i);
    %         lcohoptimum=dolperkwhheat(i);
    %         numberoptimum=pipenumber(i);
    %         else
    %         end
    %     end

   minopannualmillions=(minoperating)/1000000; 

end % end for loop over is